==> deepin-app-store_5.6.3.9.orig.tar.xz: deepin-app-store-5.6.3.9/translations/deepin-app-store_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="235"/>
        <source>Search</source>
        <translation>Vyhledávání</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="41"/>
        <source>Clear cache</source>
        <translation>Vyčistit mezipaměť</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="44"/>
        <source>Privacy Policy</source>
        <translation>Politika pro soukromí</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Vrátit</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="115"/>
        <source>App Store</source>
        <translation>Obchod s programy</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="116"/>
        <source>App Store is a software center with diverse and quality applications, supporting installation and uninstallation with one click.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <source>Search for &quot;%1&quot; in Store</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Store</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Moje poznámky</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Moje programy</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Odhlásit se</translation>
    </message>
</context>
</TS>

==> deepin-app-store_6.2.0.30.orig.tar.xz: deepin-app-store-6.2.0.30/translations/deepin-app-store_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="250"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="43"/>
        <source>Clear cache</source>
        <translation>Vyčistit mezipaměť</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="vanished">Zásady ochrany soukromí</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Vrátit zpět</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="61"/>
        <source>App Store</source>
        <translation>Obchod s aplikacemi</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="62"/>
        <source>App Store is a software center with diverse and quality applications, supporting installation and uninstallation with one click.</source>
        <translation>Obchod s aplikacemi je centrum software s rozličnými a kvalitními aplikacemi, ve kterém je možné aplikace instalovat a odinstalovávat jedním klepnutím.</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="71"/>
        <location filename="../src/app/deepin_app_store.cpp" line="73"/>
        <source>UnionTech Software Privacy Policy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <source>Search for &quot;%1&quot; in Store</source>
        <translation>Vyhledat „%1“ v obchodu</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Store</source>
        <translation>Vyhledat „%1“ v obchodu</translation>
    </message>
</context>
<context>
    <name>dstore::AccountProxy</name>
    <message>
        <location filename="../src/ui/channel/account_proxy.cpp" line="35"/>
        <source>Activate</source>
        <translation>Aktivovat</translation>
    </message>
    <message>
        <location filename="../src/ui/channel/account_proxy.cpp" line="44"/>
        <source>Your system is not activated. Please activate as soon as possible for normal use.</source>
        <translation>Váš systém není aktivován. Aktivujte ho co možná nejdříve, abyste ho mohli normálně používat.</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Moje komentáře</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Moje aplikace</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Odhlásit se</translation>
    </message>
</context>
</TS>
